@@ -44,11 +44,9 @@ except:
 
 # ---* Command *--- #
 if str(sys.argv[command]) == "append":
-    try:
-        argv_service = sys.argv[command + 1]
-        uacs.append(argv_service, verbose)
-    except:
-        print("commande usage: uacs append 'service_to_append'")
+    argv_service = sys.argv[command + 1]
+    uacs.append(argv_service, verbose)
+
 
 elif str(sys.argv[command]) == "start":
     uacs.run_daemon()
